# Analysis to go with Interactivity in Linear Diagrams
# Author: P. Chapman
# Feb 2021

# load a bunch of libraries
library("geepack")
library("ggplot2")
library("ggpubr")
library("MASS")
library("lmtest")
library("sandwich")
library("aod")



# Remember to set the working directory
# Obviously change this if the file and script live in separate folders
df <-read.csv("responses.csv")

df$group <- as.factor(df$group)
df$shape <- as.factor(df$shape)
df$changed <- as.factor(df$changed)

# Functons to do binomial response for correct and confidence.
# Could do this in one function with an argument, but then would have to
# use anonymous function in the sapply step later on.

# the number in some categories is too small for ordinal regression
# So, use logistic instead, which requires a binomial response
binomCor <- function(a){
  if (a <= 7){
    c <- 0
  } else { c <- 1}
  c
}

# as above, not enough in some categories. Some are empty.
# So, switch to logistic model, with binomial response.
binConf <- function(a){
  if (a <= 4){
    c <- 0
  } else { c <- 1}
  c
}

# calculate the binomial correct and confidence scores. 
binomCorr <- sapply(df[,5],binomCor)
binomConf <- sapply(df[,6],binConf)

# add the binomial columns to the dataframe
df$corrBinom <- binomCorr
df$confBin <- binomConf

# If we want to compare against those who changed vs. those who could not,
# then use df2.

# group S: could not change
dfS <- df[df$group == 'S',]
# group I and did change
dfIY <- df[(df$group == 'I') & (df$changed == 'Y'),]
# glue them back together
df2 <- rbind(dfS,dfIY)


######## FORMULAE #########
# Group as independent variable
fAcc.group <- formula(corrBinom ~ group*shape)
fConf.group <- formula(confBin ~ group*shape)
fTime.group <- formula(time ~ group*shape)
fConf.group.noI <- formula(confBin ~ group + shape)

# Changed as independent variable
fAcc.change <- formula(corrBinom ~ changed*shape)
fConf.change <- formula(confBin ~ changed*shape)
fTime.change <- formula(time ~ group*shape)
fConf.change.noI <- formula(confBin ~ changed + shape)


####### MODELS #######
# Using glm, with Gaussian family for time and binomial family for accuracy and confidence
# For all want the "exchangeable" covariate matrix

# accuracy. Group as independent
mAcc.group <- geeglm(fAcc.group,id=ID,data=df,family=binomial("logit"),corstr="ex")

# confidence. Group as independent
mConf.group <- geeglm(fConf.group,id=ID,data=df,family=binomial("logit"),corstr="ex")
# no interaction effect, so simplify model
mConf.group.noI <- geeglm(fConf.group.noI,id=ID,data=df,family=binomial("logit"),corstr="ex")

# time. Group as independent
mTime.group <- geeglm(fTime.group, id=ID, data=df, family=gaussian, corstr="ex")



# Using df2, it is irrelevant if using changed or group as independent, as they describe the same rows
# accuracy
mAcc.changed.2 <- geeglm(fAcc.change, id=ID, data=df2, family=binomial("logit"), corstr="ex")

# confidence
mConf.changed.2 <- geeglm(fConf.change, id=ID, data=df2, family=binomial("logit"), corstr="ex")
# no interaction effect, so simplify model
mConf.changed.2.noI <- geeglm(fConf.change.noI, id=ID, data=df2, family=binomial("logit"), corstr="ex")

# time
mTime.changed.2 <- geeglm(fTime.change, id=ID, data=df2, family=gaussian, corstr="ex")


# Using changed as the independent variable, irrespective of which group N was in.
# These are the models reported in the paper
# accuracy, changed as independent
mAcc.changed <- geeglm(fAcc.change,id=ID,data=df,family=binomial("logit"),corstr="ex")

# confidence, changed as independent
mConf.changed <- geeglm(fConf.change,id=ID,data=df,family=binomial("logit"),corstr="ex")
# no interaction effect, so simplify model
mConf.changed.noI <- geeglm(fConf.change.noI,id=ID,data=df,family=binomial("logit"),corstr="ex")

# time
mTime.changed <- geeglm(fTime.change,id=ID, data=df, family=gaussian, corstr="ex")

# vectors to check various co-efficient pairings
# B versus C
lBC <- cbind(0,0,1,-1,0,0,0,0)
# B versus D
lBD <- cbind(0,0,1,0,-1,0,0,0)
# C versus D
lCD <- cbind(0,0,0,1,-1,0,0,0)

# things to run
# wald.test(b=coef(NAMEOFMODEL), Sigma=vcov(NAMEOFMODEL),L=NAMEOFAPPROPRIATEVECTOR)

# For B-C
# accuracy
# wald.test(b=coef(mAccBin2),Sigma=vcov(mAccBin2),L=lBC)
# confidence
# wald.test(b=coef(mConf3Bin),Sigma=vcov(mConf3Bin),L=lBC)
# time
# wald.test(b=coef(mTime3),Sigma=vcov(mTime3),L=lBC)

# For B-D
# accuracy
# wald.test(b=coef(mAccBin2),Sigma=vcov(mAccBin2),L=lBD)
# confidence
# wald.test(b=coef(mConf3Bin),Sigma=vcov(mConf3Bin),L=lBD)
# time
# wald.test(b=coef(mTime3),Sigma=vcov(mTime3),L=lBD)

# For C-D
# accuracy
# wald.test(b=coef(mAccBin2),Sigma=vcov(mAccBin2),L=lCD)
# confidence
# wald.test(b=coef(mConf3Bin),Sigma=vcov(mConf3Bin),L=lCD)
# time
# wald.test(b=coef(mTime3),Sigma=vcov(mTime3),L=lCD)

### boxplots

accBox <- ggboxplot(df,x="shape",y="correct",color="group",palette="jco") + xlab("Shape") + ylab("Confidence") + ggtitle("Shape vs. Accuracy")
confBox <- ggboxplot(df,x="shape",y="confidence",color="group",palette="jco") + xlab("Shape") + ylab("Confidence") + ggtitle("Shape vs. Confidence")
timeBox <- ggboxplot(df,x="shape",y="time",color="group",palette="jco") + xlab("Shape") + ylab("Time")  + ggtitle("Shape vs. Time")

confBox2 <- ggboxplot(df2,x="shape",y="confidence",color="changed",palette="jco") + xlab("Shape") + ylab("Confidence") + ggtitle("Shape vs. Confidence")
timeBox2 <- ggboxplot(df2,x="shape",y="time",color="changed",palette="jco") + xlab("Shape") + ylab("Time")  + ggtitle("Shape vs. Time")
