# Analysis to go with Interactivity in Linear Diagrams, study 2
# Author: P. Chapman
# Feb 2021

# load a bunch of libraries
library("geepack")
library("ggplot2")
library("ggpubr")
library("MASS")
library("lmtest")
library("sandwich")
library("aod")



# Remember to set the working directory
# Obviously change this if the file and script live in separate folders
df <-read.csv("responses.csv")

df$type <- as.factor(df$type)
df$shape <- as.factor(df$shape)


# Functons to do binomial response for correct and confidence.
# Could do this in one function with an argument, but then would have to
# use anonymous function in the sapply step later on.

# the number in some categories is too small for ordinal regression
# So, use logistic instead, which requires a binomial response
binomCor <- function(a){
  if (a <= 7){
    c <- 0
  } else { c <- 1}
  c
}

# as above, not enough in some categories. Some are even empty.
# So, switch to logistic model, with binomial response.
binConf <- function(a){
  if (a <= 4){
    c <- 0
  } else { c <- 1}
  c
}

# calculate the binomial correct and confidence scores. 
binomCorr <- sapply(df[,5],binomCor)
binomConf <- sapply(df[,6],binConf)

# add the binomial columns to the dataframe
df$corrBinom <- binomCorr
df$confBin <- binomConf

# function which will create a type variable as 1,2
# for unedited, and edited. Required for geeglm
type.change <- function(a){
  if (a == 'E'){
    c <- 2
  } else { c <- 1}
  c
}

# apply above function to the type column
type.number <- sapply(df[,3],type.change)

# add the new numeric type variable to the dataframe
df$type.num <- type.number


# Working out the confidence within each type
dfE <- df[df$type == 'E',]
dfU <- df[df$type == 'U',]


######## FORMULAE #########
# Shape as independent variable, type will be the wave
fAcc <- formula(corrBinom ~ type*shape)
fConf <- formula(confBin ~ type*shape)
fTime <- formula(time ~ type*shape)

# Without interaction effects, only for accuracy and time
fAcc.noI <- formula(corrBinom ~ type + shape)
fTime.noI <- formula(time ~ type + shape)

# For each subgroup, confidence
fConf.sub <- formula(confBin ~ shape)


####### MODELS #######
# Using glm, with Gaussian family for time and binomial family for accuracy and confidence
# For all want the "exchangeable" covariate matrix

# accuracy. Shape as independent, type as wave (within-variable)
mAcc <- geeglm(fAcc,id=ID,data=df,family=binomial("logit"),corstr="ex", waves=type.num)
# summary(mAcc) for the output

# no interaction effect for mAcc, so rerun as simpler model
mAcc.noI <- geeglm(fAcc.noI,id=ID,data=df,family=binomial("logit"),corstr="ex", waves=type.num)
# summary(mAcc.noI)

# CONCLUSION: no difference for shape, but edited more accurate than unedited.

# confidence. Shape as independent, type as wave (within-variable)
mConf <- geeglm(fConf,id=ID,data=df,family=binomial("logit"),corstr="ex", waves=type.num)
# summary(mConf)

# interaction effect present, and two main effects. Do breakdown:

# working things out for the subgroups
# edited questions
mConf.E <- geeglm(fConf.sub,id=ID,data=dfE,family=binomial("logit"),corstr="ex")

# unedited questions
mConf.U <- geeglm(fConf.sub,id=ID,data=dfU,family=binomial("logit"),corstr="ex")

# CONCLUSION: no difference for U, but shape D is less confident for E.
# CONCLUSION: generally higher confidence for E than U

# time. Shape as independent, type as wave (within-variable)
mTime <- geeglm(fTime, id=ID, data=df, family=gaussian, corstr="ex", waves=type.num)
# summary(mTime)

mTime.noI <- geeglm(fTime.noI, id=ID, data=df, family=gaussian, corstr="ex", waves=type.num)

# CONCLUSION: nothing significant.

### boxplots

accBox <- ggboxplot(df,x="shape",y="correct",color="group",palette="jco") + xlab("Shape") + ylab("Confidence") + ggtitle("Shape vs. Accuracy")
confBox <- ggboxplot(df,x="shape",y="confidence",color="group",palette="jco") + xlab("Shape") + ylab("Confidence") + ggtitle("Shape vs. Confidence")
timeBox <- ggboxplot(df,x="shape",y="time",color="group",palette="jco") + xlab("Shape") + ylab("Time")  + ggtitle("Shape vs. Time")


